==> 1.1.1.tar.gz: doc/WireguardApi.md <==
# forestvpn_api.api.WireguardApi

## Load the API package
```dart
import 'package:forestvpn_api/api.dart';
```

All URIs are relative to *https://api.forestvpn.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createProfile**](WireguardApi.md#createProfile) | **POST** /wg/profiles/ | Create new WireGuard profile
[**deleteProfile**](WireguardApi.md#deleteProfile) | **DELETE** /wg/profiles/{profileId}/ | Delete WireGuarg profile
[**getProfile**](WireguardApi.md#getProfile) | **GET** /wg/profiles/{profileId}/ | Retrieve WireGuarg profile
[**getProfiles**](WireguardApi.md#getProfiles) | **GET** /wg/profiles/ | Retrieve list of WireGuard profiles
[**updateProfile**](WireguardApi.md#updateProfile) | **PATCH** /wg/profiles/{profileId}/ | Update profile


# **createProfile**
> WireGuardProfile createProfile(request)

Create new WireGuard profile

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = WireguardApi();
var request = WireGuardProfileCreateRequest(); // WireGuardProfileCreateRequest | 

try { 
    var result = api_instance.createProfile(request);
    print(result);
} catch (e) {
    print("Exception when calling WireguardApi->createProfile: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**WireGuardProfileCreateRequest**](WireGuardProfileCreateRequest.md)|  | [optional] 

### Return type

[**WireGuardProfile**](WireGuardProfile.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteProfile**
> deleteProfile(profileId)

Delete WireGuarg profile

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = WireguardApi();
var profileId = 38400000-8cf0-11bd-b23e-10b96e4ef00d; // String | 

try { 
    api_instance.deleteProfile(profileId);
} catch (e) {
    print("Exception when calling WireguardApi->deleteProfile: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **profileId** | [**String**](.md)|  | [default to null]

### Return type

void (empty response body)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getProfile**
> WireGuardProfile getProfile(profileId)

Retrieve WireGuarg profile

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = WireguardApi();
var profileId = 38400000-8cf0-11bd-b23e-10b96e4ef00d; // String | 

try { 
    var result = api_instance.getProfile(profileId);
    print(result);
} catch (e) {
    print("Exception when calling WireguardApi->getProfile: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **profileId** | [**String**](.md)|  | [default to null]

### Return type

[**WireGuardProfile**](WireGuardProfile.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getProfiles**
> List<WireGuardProfile> getProfiles()

Retrieve list of WireGuard profiles

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = WireguardApi();

try { 
    var result = api_instance.getProfiles();
    print(result);
} catch (e) {
    print("Exception when calling WireguardApi->getProfiles: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**List<WireGuardProfile>**](WireGuardProfile.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateProfile**
> WireGuardProfile updateProfile(profileId, request)

Update profile

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = WireguardApi();
var profileId = 38400000-8cf0-11bd-b23e-10b96e4ef00d; // String | 
var request = WireGuardProfileUpdateRequest(); // WireGuardProfileUpdateRequest | 

try { 
    var result = api_instance.updateProfile(profileId, request);
    print(result);
} catch (e) {
    print("Exception when calling WireguardApi->updateProfile: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **profileId** | [**String**](.md)|  | [default to null]
 **request** | [**WireGuardProfileUpdateRequest**](WireGuardProfileUpdateRequest.md)|  | 

### Return type

[**WireGuardProfile**](WireGuardProfile.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> 1.2.4.tar.gz: doc/WireguardApi.md <==
# forestvpn_api.api.WireguardApi

## Load the API package
```dart
import 'package:forestvpn_api/api.dart';
```

All URIs are relative to *https://api.forestvpn.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createProfile**](WireguardApi.md#createprofile) | **POST** /wg/profiles/ | Create new WireGuard profile
[**deleteProfile**](WireguardApi.md#deleteprofile) | **DELETE** /wg/profiles/{profileId}/ | Delete WireGuarg profile
[**getProfile**](WireguardApi.md#getprofile) | **GET** /wg/profiles/{profileId}/ | Retrieve WireGuarg profile
[**getProfiles**](WireguardApi.md#getprofiles) | **GET** /wg/profiles/ | Retrieve list of WireGuard profiles
[**updateProfile**](WireguardApi.md#updateprofile) | **PATCH** /wg/profiles/{profileId}/ | Update profile


# **createProfile**
> WireGuardProfile createProfile(request)

Create new WireGuard profile

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

final api_instance = WireguardApi();
final request = WireGuardProfileCreateRequest(); // WireGuardProfileCreateRequest | 

try { 
    final result = api_instance.createProfile(request);
    print(result);
} catch (e) {
    print('Exception when calling WireguardApi->createProfile: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**WireGuardProfileCreateRequest**](WireGuardProfileCreateRequest.md)|  | [optional] 

### Return type

[**WireGuardProfile**](WireGuardProfile.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteProfile**
> deleteProfile(profileId)

Delete WireGuarg profile

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

final api_instance = WireguardApi();
final profileId = 38400000-8cf0-11bd-b23e-10b96e4ef00d; // String | 

try { 
    api_instance.deleteProfile(profileId);
} catch (e) {
    print('Exception when calling WireguardApi->deleteProfile: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **profileId** | [**String**](.md)|  | 

### Return type

void (empty response body)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getProfile**
> WireGuardProfile getProfile(profileId)

Retrieve WireGuarg profile

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

final api_instance = WireguardApi();
final profileId = 38400000-8cf0-11bd-b23e-10b96e4ef00d; // String | 

try { 
    final result = api_instance.getProfile(profileId);
    print(result);
} catch (e) {
    print('Exception when calling WireguardApi->getProfile: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **profileId** | [**String**](.md)|  | 

### Return type

[**WireGuardProfile**](WireGuardProfile.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getProfiles**
> List<WireGuardProfile> getProfiles()

Retrieve list of WireGuard profiles

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

final api_instance = WireguardApi();

try { 
    final result = api_instance.getProfiles();
    print(result);
} catch (e) {
    print('Exception when calling WireguardApi->getProfiles: $e\n');
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**List<WireGuardProfile>**](WireGuardProfile.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateProfile**
> WireGuardProfile updateProfile(profileId, request)

Update profile

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

final api_instance = WireguardApi();
final profileId = 38400000-8cf0-11bd-b23e-10b96e4ef00d; // String | 
final request = WireGuardProfileUpdateRequest(); // WireGuardProfileUpdateRequest | 

try { 
    final result = api_instance.updateProfile(profileId, request);
    print(result);
} catch (e) {
    print('Exception when calling WireguardApi->updateProfile: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **profileId** | [**String**](.md)|  | 
 **request** | [**WireGuardProfileUpdateRequest**](WireGuardProfileUpdateRequest.md)|  | 

### Return type

[**WireGuardProfile**](WireGuardProfile.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
